@@ -1,11 +1,12 @@
 r"""
 # cx_Oracle_async
-[![fury](https://badge.fury.io/py/cx-Oracle-async.svg)](https://badge.fury.io/py/cx-Oracle-async)
+[![fury](https://img.shields.io/pypi/v/cx-Oracle-async.svg)](https://pypi.org/project/cx-Oracle-async/)
 [![licence](https://img.shields.io/github/license/GoodManWEN/cx_Oracle_async)](https://github.com/GoodManWEN/cx_Oracle_async/blob/master/LICENSE)
 [![pyversions](https://img.shields.io/pypi/pyversions/cx-Oracle-async.svg)](https://pypi.org/project/cx-Oracle-async/)
 [![Publish](https://github.com/GoodManWEN/cx_Oracle_async/workflows/Publish/badge.svg)](https://github.com/GoodManWEN/cx_Oracle_async/actions?query=workflow:Publish)
 [![Build](https://github.com/GoodManWEN/cx_Oracle_async/workflows/Build/badge.svg)](https://github.com/GoodManWEN/cx_Oracle_async/actions?query=workflow:Build)
 [![Docs](https://readthedocs.org/projects/cx-oracle-async/badge/?version=latest)](https://readthedocs.org/projects/cx-oracle-async/)
+[![Visitors](https://visitor-badge.glitch.me/badge?page_id=goodmanwen.cx_Oracle_async&style=flat-square&color=0088cc)](https://github.com/GoodManWEN/cx_Oracle_async/)
 
 A very simple asynchronous wrapper that allows you to get access to the Oracle database in asyncio programs.
 
@@ -70,14 +71,15 @@ async def main():
 
 if __name__ == '__main__':
     asyncio.run(main())
-```"""
-__version__ = '0.3.0'
+```
+"""
+__version__ = '0.3.2'
 
 from .utils import create_pool , makedsn , DEQ_NO_WAIT , DEQ_WAIT_FOREVER
 
 __all__ = (
-	'create_pool',
-	'makedsn',
+    'create_pool',
+    'makedsn',
     'DEQ_NO_WAIT',
     'DEQ_WAIT_FOREVER'
-)
\ No newline at end of file
+)
